@@ -1,3 +1,27 @@
+# Copyright (c) 2021  StorPool <support@storpool.com>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+# 1. Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+# 2. Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in the
+#    documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
+# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+# SUCH DAMAGE.
+#
 """
 Support for different OS distributions and StorPool build variants.
 
@@ -262,7 +286,7 @@ else:
     BytesType = str
 
 
-VERSION = "2.0.0"
+VERSION = "2.1.1"
 FORMAT_VERSION = (1, 3)
 
 
@@ -537,10 +561,39 @@ _VARIANT_DEF = [
             },
         },
     ),
+    VariantUpdate(
+        name="UBUNTU2110",
+        descr="Ubuntu 21.10 LTS (Impish Indri)",
+        parent="DEBIAN12",
+        detect=Detect(
+            filename="/etc/os-release",
+            regex=re.compile(
+                r"^ PRETTY_NAME= .* (?: Ubuntu \s+ 21 \. 10 | Mint \s+ 21 ) ",
+                re.X,
+            ),
+            os_id="ubuntu",
+            os_version_regex=re.compile(r"^21\.10$"),
+        ),
+        updates={
+            "repo": {
+                "vendor": "ubuntu",
+                "codename": "impish",
+            },
+            "package": {
+                "CPUPOWER": "linux-tools-generic",
+                "MCELOG": "bash",
+            },
+            "builder": {
+                "alias": "ubuntu-21.10",
+                "base_image": "ubuntu:impish",
+                "branch": "ubuntu/impish",
+            },
+        },
+    ),
     VariantUpdate(
         name="UBUNTU2004",
         descr="Ubuntu 20.04 LTS (Focal Fossa)",
-        parent="DEBIAN11",
+        parent="UBUNTU2110",
         detect=Detect(
             filename="/etc/os-release",
             regex=re.compile(
@@ -556,10 +609,6 @@ _VARIANT_DEF = [
                 "codename": "focal",
             },
             "min_sys_python": "3.8",
-            "package": {
-                "CPUPOWER": "linux-tools-generic",
-                "MCELOG": "bash",
-            },
             "builder": {
                 "alias": "ubuntu-20.04",
                 "base_image": "ubuntu:focal",
@@ -655,7 +704,7 @@ _VARIANT_DEF = [
                     "rpm",
                     "-qa",
                     "--qf",
-                    r"%{Name}\t%{Version}\t%{Arch}\tii\n",
+                    r"%{Name}\t%{EVR}\t%{Arch}\tii\n",
                     "--",
                 ],
                 purge=[
@@ -1179,7 +1228,7 @@ def update_namedtuple(data, updates):
                 )
             )
 
-    updated = type(data)(**newv)  # type: ignore
+    updated = type(data)(**newv)
     return updated
 
 
