@@ -1,3 +1,28 @@
+/*
+ * Copyright (c) 2021  StorPool <support@storpool.com>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
 //! Perform tasks related to the OS distribution and version.
 //!
 //! The `storpool_variant` tool may be used to:
@@ -27,7 +52,6 @@ use sp_variant::{self, Variant, VariantDefTop};
 struct RepoType<'a> {
     name: &'a str,
     extension: &'a str,
-    url: &'a str,
 }
 
 #[derive(Debug)]
@@ -71,17 +95,14 @@ const REPO_TYPES: &[RepoType; 3] = &[
     RepoType {
         name: "contrib",
         extension: "",
-        url: "https://repo.storpool.com/public/",
     },
     RepoType {
         name: "staging",
         extension: "-staging",
-        url: "https://repo.storpool.com/public/",
     },
     RepoType {
         name: "infra",
         extension: "-infra",
-        url: "https://intrepo.storpool.com/repo/",
     },
 ];
 
@@ -109,7 +130,6 @@ fn run_command(cmdvec: &[String], action: &str, noop: bool) {
         println!("Would run `{}`", cmdstr);
         return;
     }
-    println!("Running `{}`", cmdstr);
 
     let status = process::Command::new(&cmdvec[0])
         .args(&cmdvec[1..])
@@ -231,6 +251,21 @@ fn repo_add_deb(var: &Variant, config: RepoAddConfig, vdir: &str, repo: &sp_vari
 }
 
 fn repo_add_yum(config: RepoAddConfig, vdir: &str, repo: &sp_variant::YumRepo) {
+    let run_yum_install_certs = || {
+        run_command(
+            &[
+                "yum".to_string(),
+                "--disablerepo=storpool-*".to_string(),
+                "install".to_string(),
+                "-q".to_string(),
+                "-y".to_string(),
+                "ca-certificates".to_string(),
+            ],
+            "Could not update the package database",
+            config.noop,
+        );
+    };
+
     let copy_yumdef_file = || {
         let yumdef_orig = repo.yumdef.rsplit('/').next().unwrap();
         let (yumdef_base, yumdef_ext) = yumdef_orig.rsplit_once('.').unwrap();
@@ -277,6 +312,7 @@ fn repo_add_yum(config: RepoAddConfig, vdir: &str, repo: &sp_variant::YumRepo) {
         );
     };
 
+    run_yum_install_certs();
     copy_yumdef_file();
     copy_keyring_file();
     run_rpmkeys();
@@ -334,9 +370,8 @@ fn cmd_command_run(varfull: &VariantDefTop, config: CommandRunConfig) {
 }
 
 fn cmd_show(varfull: &VariantDefTop, config: ShowConfig) {
-    let full = String::from_utf8(sp_variant::data::get_json_def()).unwrap();
     match config.name == "all" {
-        true => print!("{}", full),
+        true => print!("{}", serde_json::to_string(varfull).unwrap()),
         false => {
             let var = match &*config.name {
                 "current" => {
@@ -350,7 +385,7 @@ fn cmd_show(varfull: &VariantDefTop, config: ShowConfig) {
                     version: sp_variant::VariantFormatVersion { major, minor },
                 },
                 variant: var.clone(),
-                version: sp_variant::get_program_version(),
+                version: sp_variant::get_program_version().to_string(),
             };
             println!("{}", serde_json::to_string_pretty(&single).unwrap());
         }
@@ -359,11 +394,11 @@ fn cmd_show(varfull: &VariantDefTop, config: ShowConfig) {
 
 fn main() {
     let varfull = sp_variant::build_variants();
-    let program_version = sp_variant::get_program_version_from(&varfull);
+    let program_version = sp_variant::get_program_version_from(varfull);
     let app = {
         let valid_repo_types: Vec<&str> = REPO_TYPES.iter().map(|rtype| rtype.name).collect();
         clap::App::new("storpool_variant")
-            .version(&**program_version)
+            .version(program_version)
             .author("StorPool <support@storpool.com>")
             .about("storpool_variant: handle OS distribution- and version-specific tasks")
             .subcommand(
@@ -497,21 +532,18 @@ fn main() {
     match &matches.subcommand {
         Some(subcommand) => {
             let (subc_name, subc_matches) = get_subc_name(subcommand);
-            match cmds.iter().find(|(name, _)| *name == subc_name) {
-                Some((_, handler)) => {
-                    let mode = handler(subc_matches);
-                    match mode {
-                        Mode::Features => cmd_features(&varfull),
-                        mode => match mode {
-                            Mode::CommandList => cmd_command_list(&varfull),
-                            Mode::CommandRun(config) => cmd_command_run(&varfull, config),
-                            Mode::Detect => cmd_detect(&varfull),
-                            Mode::Features => panic!("nope"),
-                            Mode::RepoAdd(config) => cmd_repo_add(&varfull, config),
-                            Mode::Show(config) => cmd_show(&varfull, config),
-                        },
-                    }
-                }
+            match cmds
+                .iter()
+                .find_map(|(name, handler)| (*name == subc_name).then(|| handler))
+            {
+                Some(handler) => match handler(subc_matches) {
+                    Mode::Features => cmd_features(varfull),
+                    Mode::CommandList => cmd_command_list(varfull),
+                    Mode::CommandRun(config) => cmd_command_run(varfull, config),
+                    Mode::Detect => cmd_detect(varfull),
+                    Mode::RepoAdd(config) => cmd_repo_add(varfull, config),
+                    Mode::Show(config) => cmd_show(varfull, config),
+                },
                 None => expect_exit::exit(matches.usage()),
             }
         }
